emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Emacs-diffs] feature/gnus-select d27fdc5 085/218: Fix an error in tramp


From: Andrew G Cohen
Subject: [Emacs-diffs] feature/gnus-select d27fdc5 085/218: Fix an error in tramp-archive-test42-auto-load
Date: Fri, 14 Dec 2018 03:35:05 -0500 (EST)

branch: feature/gnus-select
commit d27fdc54d8bd9b1e5ead1a2243a991baa539fe2b
Author: Michael Albinus <address@hidden>
Commit: Andrew G Cohen <address@hidden>

    Fix an error in tramp-archive-test42-auto-load
    
    * test/lisp/net/tramp-archive-tests.el (tramp-archive-test42-auto-load):
    Do not use "/ssh::" as test directory, it could harm.  (Bug#30807)
---
 test/lisp/net/tramp-archive-tests.el | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/test/lisp/net/tramp-archive-tests.el 
b/test/lisp/net/tramp-archive-tests.el
index 33916f8..a3201bd 100644
--- a/test/lisp/net/tramp-archive-tests.el
+++ b/test/lisp/net/tramp-archive-tests.el
@@ -809,7 +809,7 @@ This tests also `file-executable-p', `file-writable-p' and 
`set-file-modes'."
   (skip-unless (tramp-archive--test-emacs27-p))
 
   ;; tramp-archive is neither loaded at Emacs startup, nor when
   ;; loading a file like "/ssh::" (which loads Tramp).
   (let ((default-directory (expand-file-name temporary-file-directory))
        (code
         "(progn \
@@ -818,7 +818,7 @@ This tests also `file-executable-p', `file-writable-p' and 
`set-file-modes'."
            (file-attributes %S \"/\") \
            (message \"tramp-archive loaded: %%s %%s\" \
               (featurep 'tramp) (featurep 'tramp-archive)))"))
-    (dolist (file `("/ssh::foo" ,(concat tramp-archive-test-archive "foo")))
+    (dolist (file `("/mock::foo" ,(concat tramp-archive-test-archive "foo")))
       (should
        (string-match
        (format
@@ -809,7 +809,7 @@ This tests also `file-executable-p', `file-writable-p' and 
 
   ;; tramp-archive is neither loaded at Emacs startup, nor when
-  ;; loading a file like "/ssh::" (which loads Tramp).
+  ;; loading a file like "/mock::foo" (which loads Tramp).
   (let ((default-directory (expand-file-name temporary-file-directory))
        (code



reply via email to

[Prev in Thread] Current Thread [Next in Thread]